"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander = __importStar(require("commander"));
const fs = __importStar(require("fs"));
const path = __importStar(require("path"));
const convert_1 = require("./convert");
const readline_1 = __importDefault(require("readline"));
const util_1 = __importDefault(require("util"));
const child_process_1 = require("child_process");
const exec = util_1.default.promisify(child_process_1.exec);
const program = new commander.Command();
const pkg = JSON.parse(fs.readFileSync(path.resolve(__dirname, '../package.json'), 'utf8'));
program
    .name('flowts')
    .version(pkg.version)
    .description('Flow to TypeScript migration tool')
    .option('-R, --no-recast', 'use babel generator instead of recast', true)
    .option('-P, --no-prettier', 'do not run prettier on converted code', true)
    .option('--no-gitignore', 'also convert files which are listed in gitignore files', true)
    .usage('[options] ./path/to/project')
    .option('--no-allow-js', 'convert all JS files to TypeScript(including without Flow)', true)
    .option('--keep-annotated-js', 'do not rename js files without types even if there is @flow/@noflow annotation', false)
    .option('--interactive-rename', 'Wait for interactive confirmation after renaming, before writing converted code (allowing to have separate commit to better preserve file history)', false)
    .option('--commit-rename-command <commitRenameCommand>', 'Command to commit file renames. To be used instead of interactive-rename', '')
    .option('-i, --include <includeGlob>', 'Glob expression of files to include, default: "**/*.{js,mjs,jsx,js.flow}"', '**/*.{js,mjs,jsx,js.flow}')
    .option('-x, --exclude <excludeGlob>', 'Additional excludes glob expression (by default node_modules and files from .gitignore is excluded)', (a, b) => [...b, a], [])
    .option('--dry-run', 'Do not save changes after migration', false)
    .option('--legacy-imports', 'Do not use mixed type/value imports allowed in TS 4.5+', false)
    .option('--remove-all-import-extensions', 'When enabled - removes all converted file extensions in relative imports (by default only extensions for converted files are removed)', false)
    .option('--keep-import-extensions', 'Disables removal of converted file extensions in imports for converted files(can to result in unresolved imports, if for example ".js" was in import for converted file)', false)
    .parse(process.argv);
const args = program.args;
const opts = program.opts();
if (args.length === 0) {
    console.error('Please specify project root');
    process.exit(1);
}
if (args.length > 1) {
    console.error('Only one project root can be specified');
    process.exit(1);
}
const { exclude: excludeGlobs, interactiveRename, commitRenameCommand } = opts, restOptions = __rest(opts, ["exclude", "interactiveRename", "commitRenameCommand"]);
const convertOptions = Object.assign(Object.assign({}, restOptions), { exclude: ['**/node_modules/**', ...excludeGlobs], renameHook: interactiveRename || commitRenameCommand
        ? () => __awaiter(void 0, void 0, void 0, function* () {
            if (commitRenameCommand) {
                const { stdout, stderr } = yield exec(commitRenameCommand);
                console.log('stdout:', stdout);
                console.log('stderr:', stderr);
            }
            else {
                yield new Promise(resolve => {
                    const rl = readline_1.default.createInterface({
                        input: process.stdin,
                        output: process.stdout,
                    });
                    rl.question('Press <enter> to write converted code:', () => {
                        rl.close();
                        resolve(undefined);
                    });
                });
            }
        })
        : () => __awaiter(void 0, void 0, void 0, function* () {
            // do not wait - continue to writing the results
        }) });
(0, convert_1.convert)(args[0], convertOptions).then(() => {
    console.log('done');
    process.exit(0);
}, e => {
    console.error(e);
    process.exit(1);
});
//# sourceMappingURL=cli.js.map