"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.convert = void 0;
const babel = __importStar(require("@babel/core"));
const fs_1 = require("fs");
const globby_1 = __importDefault(require("globby"));
const path = __importStar(require("path"));
const jest_diff_1 = require("jest-diff");
const detectOptions_1 = require("./detectOptions");
const babel_plugin_recast_1 = __importDefault(require("@flowts/babel-plugin-recast"));
const verify_1 = require("./verify/verify");
const removeImportExtensionPlugin_1 = __importDefault(require("./removeImportExtensionPlugin"));
const sharedParserPlugins_1 = require("./sharedParserPlugins");
const ora_1 = __importDefault(require("ora"));
const fixFlowPragmaPlugin_1 = __importDefault(require("./fixFlowPragmaPlugin"));
const convertFile_1 = require("./convertFile");
function convert(cwd, opts) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        console.log('options:', opts);
        const spinner = (0, ora_1.default)().start(`processing files in ${cwd}`);
        const transformPlugins = [];
        if (opts.recast) {
            transformPlugins.push(babel_plugin_recast_1.default);
        }
        const files = yield (0, globby_1.default)(opts.include, {
            cwd,
            onlyFiles: true,
            dot: true,
            ignore: opts.exclude,
            gitignore: opts.gitignore,
        });
        const filesInfo = new Map();
        spinner.info('detecting options for the files');
        let totalStr = `${files.length}`;
        let currentCount = 0;
        for (const file of files) {
            const currentStr = `${currentCount}`.padStart(totalStr.length, ' ');
            spinner.start(`[${currentStr}/${totalStr}] ${file}`);
            try {
                const filepath = path.join(cwd, file);
                const source = yield fs_1.promises.readFile(filepath, { encoding: 'utf8' });
                const fileOptions = (0, detectOptions_1.detectOptions)(source, file);
                const isFlow = fileOptions.hasTypes ||
                    fileOptions.isDefinitionFile ||
                    (!opts.keepAnnotatedJs &&
                        (fileOptions.hasFlowAnnotation || fileOptions.hasNoFlowAnnotation));
                const isConverted = isFlow || !opts.allowJs;
                const info = {
                    file,
                    source,
                    isFlow,
                    isConverted,
                    fileOptions,
                };
                filesInfo.set(file, info);
            }
            catch (e) {
                spinner.fail(file);
                spinner.fail('error while trying to detect options');
                console.error(e);
                spinner.start();
            }
            currentCount += 1;
        }
        spinner.succeed('finished analysing source files');
        spinner.info('converting code to TypeScript');
        const results = [];
        totalStr = `${files.length}`;
        currentCount = 0;
        for (const file of files) {
            const currentStr = `${currentCount}`.padStart(totalStr.length, ' ');
            spinner.start(`[${currentStr}/${totalStr}] ${file}`);
            const info = filesInfo.get(file);
            if (!info) {
                spinner.warn('file info missing - check log for errors');
                continue;
            }
            try {
                const { file, source, fileOptions: { isJSX }, isFlow, } = info;
                const isDefinitionFile = /\.js\.flow$/i.test(file);
                const targetExt = isJSX ? '.tsx' : isDefinitionFile ? '.d.ts' : '.ts';
                const targetFileName = file.replace(/(?:\.jsx?|\.js\.flow)$/i, targetExt);
                const sourceFilePath = path.join(cwd, file);
                const targetFilePath = path.join(cwd, targetFileName);
                const isConvertedFile = (source) => {
                    if (opts.removeAllImportExtensions) {
                        return /^\./.test(source);
                    }
                    const normalizedPath = path
                        .resolve(path.dirname(sourceFilePath), source)
                        .substr(path.resolve(cwd).length + 1);
                    const requestedFileInfo = filesInfo.get(normalizedPath);
                    return requestedFileInfo && requestedFileInfo.isConverted;
                };
                const flowParserPlugins = [];
                flowParserPlugins.push(['flow', { enums: true }]);
                if (isJSX) {
                    flowParserPlugins.push('jsx');
                }
                const codeNoExtensions = opts.keepImportExtensions
                    ? source
                    : (_a = (yield babel.transformAsync(source, {
                        compact: false,
                        babelrc: false,
                        configFile: false,
                        filename: sourceFilePath,
                        plugins: [
                            ...transformPlugins,
                            [removeImportExtensionPlugin_1.default, { isConvertedFile }],
                        ],
                        generatorOpts: {
                            decoratorsBeforeExport: true,
                        },
                        parserOpts: {
                            allowReturnOutsideFunction: true,
                            plugins: [...sharedParserPlugins_1.sharedParserPlugins, ...flowParserPlugins],
                        },
                    }))) === null || _a === void 0 ? void 0 : _a.code;
                if (codeNoExtensions === null) {
                    throw new Error('babel.transformAsync returned null - probably there is some configuration error');
                }
                if (!isFlow && opts.allowJs) {
                    let code;
                    code = codeNoExtensions;
                    if (info.fileOptions.hasFlowAnnotation ||
                        info.fileOptions.hasNoFlowAnnotation) {
                        const fixed = yield babel.transformAsync(codeNoExtensions, {
                            compact: false,
                            babelrc: false,
                            configFile: false,
                            filename: sourceFilePath,
                            plugins: [...transformPlugins, fixFlowPragmaPlugin_1.default],
                            generatorOpts: {
                                decoratorsBeforeExport: true,
                            },
                            parserOpts: {
                                allowReturnOutsideFunction: true,
                                plugins: [...sharedParserPlugins_1.sharedParserPlugins, ...flowParserPlugins],
                            },
                        });
                        if (fixed === null) {
                            throw new Error('babel.transformAsync returned null - probably there is some configuration error');
                        }
                        code = fixed.code;
                    }
                    if (filesInfo)
                        results.push({
                            isConverted: false,
                            sourceFilePath,
                            targetFilePath,
                            source,
                            result: code,
                            isValid: true,
                        });
                    continue;
                }
                const result = yield (0, convertFile_1.convertFile)(codeNoExtensions, {
                    sourceFilePath,
                    targetFilePath,
                    recast: opts.recast,
                    prettier: opts.prettier,
                    fileOptions: info.fileOptions,
                    legacyImports: opts.legacyImports,
                    logger: {
                        warn(mesage) {
                            spinner.warn(sourceFilePath);
                            spinner.warn(mesage);
                        },
                        log(mesage) {
                            spinner.info(sourceFilePath);
                            spinner.info(mesage);
                        },
                        error(mesage) {
                            spinner.fail(sourceFilePath);
                            spinner.fail(mesage);
                        },
                    },
                    getTypeFixesBabelPlugins: opts.getTypeFixesBabelPlugins,
                    removeImportExtensions: false,
                });
                // delay to update the ui
                yield new Promise(r => setTimeout(r, 1));
                let isValid = true;
                if (!isDefinitionFile) {
                    // verify only actual sources, but skip it for definition files
                    const verificationResult = (0, verify_1.verify)(source, result, isJSX, sourceFilePath, targetFilePath, opts.keepImportExtensions ? false : isConvertedFile);
                    if (!verificationResult.isEqual) {
                        spinner.fail(targetFilePath);
                        spinner.fail('verification failed, diff after stripping type annotations:');
                        const changes = (0, jest_diff_1.diff)(verificationResult.src, verificationResult.tgt, {
                            contextLines: 5,
                            // show smaller diff of issues found instead of complete file diff
                            expand: false,
                        });
                        console.log(changes);
                        isValid = false;
                    }
                }
                results.push({
                    isConverted: true,
                    sourceFilePath,
                    targetFilePath,
                    source,
                    result,
                    isValid,
                });
            }
            catch (e) {
                spinner.fail(file);
                spinner.fail('error while trying to convert');
                console.error(e);
            }
            currentCount += 1;
        }
        spinner.info('renaming converted files');
        totalStr = `${results.length}`;
        currentCount = 0;
        for (const { isConverted, sourceFilePath, targetFilePath } of results) {
            const currentStr = `${currentCount}`.padStart(totalStr.length, ' ');
            if (!opts.dryRun) {
                spinner.start(`[${currentStr}/${totalStr}] ${sourceFilePath}`);
                if (isConverted) {
                    yield fs_1.promises.rename(sourceFilePath, targetFilePath);
                    const maybeJestSnapshotPath = path.join(path.dirname(sourceFilePath), '__snapshots__', path.basename(sourceFilePath) + '.snap');
                    let snapshotEsists = false;
                    try {
                        snapshotEsists = (yield fs_1.promises.stat(maybeJestSnapshotPath)).isFile();
                    }
                    catch (e) {
                        // ignored
                    }
                    if (snapshotEsists) {
                        const targetJestSnapshotPath = path.join(path.dirname(targetFilePath), '__snapshots__', path.basename(targetFilePath) + '.snap');
                        yield fs_1.promises.rename(maybeJestSnapshotPath, targetJestSnapshotPath);
                    }
                }
                // delay to update the ui
                yield new Promise(r => setTimeout(r, 1));
            }
            currentCount += 1;
        }
        spinner.succeed('renamed converted files');
        if (opts.renameHook) {
            yield opts.renameHook();
        }
        spinner.info('writing converted files');
        totalStr = `${results.length}`;
        currentCount = 0;
        for (const { isConverted, sourceFilePath, targetFilePath, source, result, isValid, } of results) {
            const currentStr = `${currentCount}`.padStart(totalStr.length, ' ');
            if (!opts.dryRun) {
                spinner.start(`[${currentStr}/${totalStr}] ${sourceFilePath}`);
                if (isConverted) {
                    yield fs_1.promises.writeFile(targetFilePath, result);
                    if (!isValid) {
                        yield fs_1.promises.writeFile(sourceFilePath, source);
                    }
                }
                else {
                    if (source !== result) {
                        yield fs_1.promises.writeFile(sourceFilePath, result);
                    }
                }
                // delay to update the ui
                yield new Promise(r => setTimeout(r, 1));
            }
            currentCount += 1;
        }
        const toReview = results
            .filter(r => !r.isValid && r.isConverted)
            .map(r => r.sourceFilePath);
        if (toReview.length) {
            spinner.warn(`Files to review:
${toReview.join('\n')}
`);
        }
        // count stats about converted code base
        let cloc = 0;
        for (const { isConverted, source, isValid } of results) {
            if (isConverted && isValid) {
                cloc += source.split(/\r\n|\r|\n/).length;
            }
        }
        spinner.succeed(`converted ${cloc} lines of code`);
    });
}
exports.convert = convert;
//# sourceMappingURL=convert.js.map