"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertFile = void 0;
const babel = __importStar(require("@babel/core"));
const prettier = __importStar(require("prettier"));
const babel_plugin_recast_1 = __importDefault(require("@flowts/babel-plugin-recast"));
const tsTypesPlugin_1 = __importDefault(require("./tsTypesPlugin"));
const removeImportExtensionPlugin_1 = __importDefault(require("./removeImportExtensionPlugin"));
const sharedParserPlugins_1 = require("./sharedParserPlugins");
const detectOptions_1 = require("./detectOptions");
const babel_plugin_flow_to_typescript_1 = __importDefault(require("@zxbodya/babel-plugin-flow-to-typescript"));
function convertFile(source, opts) {
    var _a, _b, _c, _d, _e, _f;
    return __awaiter(this, void 0, void 0, function* () {
        const logger = (_a = opts === null || opts === void 0 ? void 0 : opts.logger) !== null && _a !== void 0 ? _a : console;
        const removeImportExtensions = (_b = opts === null || opts === void 0 ? void 0 : opts.removeImportExtensions) !== null && _b !== void 0 ? _b : true;
        const sourceFilePath = (_c = opts === null || opts === void 0 ? void 0 : opts.sourceFilePath) !== null && _c !== void 0 ? _c : 'source.js';
        const targetFilePath = (_d = opts === null || opts === void 0 ? void 0 : opts.targetFilePath) !== null && _d !== void 0 ? _d : 'target.ts';
        const transformPlugins = [];
        if ((_e = opts === null || opts === void 0 ? void 0 : opts.recast) !== null && _e !== void 0 ? _e : true) {
            transformPlugins.push(babel_plugin_recast_1.default);
        }
        const fileOptions = (opts === null || opts === void 0 ? void 0 : opts.fileOptions) || (0, detectOptions_1.detectOptions)(source, sourceFilePath);
        const isJSX = fileOptions.isJSX;
        const isConvertedFile = (source) => {
            return /^\./.test(source);
        };
        const flowParserPlugins = [];
        flowParserPlugins.push(['flow', { enums: true }]);
        if (isJSX) {
            flowParserPlugins.push('jsx');
        }
        const tsSyntax = yield babel.transformAsync(source, {
            compact: false,
            babelrc: false,
            configFile: false,
            filename: sourceFilePath,
            plugins: [
                ...transformPlugins,
                [babel_plugin_flow_to_typescript_1.default, { isJSX, legacyImports: !!(opts === null || opts === void 0 ? void 0 : opts.legacyImports), logger }],
            ],
            generatorOpts: {
                decoratorsBeforeExport: true,
            },
            parserOpts: {
                allowReturnOutsideFunction: true,
                plugins: [...sharedParserPlugins_1.sharedParserPlugins, ...flowParserPlugins],
            },
        });
        if (tsSyntax === null) {
            throw new Error('babel.transformAsync returned null - probably there is some configuration error');
        }
        const postMigrationFixes = [];
        if (removeImportExtensions)
            postMigrationFixes.push([removeImportExtensionPlugin_1.default, { isConvertedFile }]);
        postMigrationFixes.push([tsTypesPlugin_1.default, { isJSX }]);
        const additionalFixes = (opts === null || opts === void 0 ? void 0 : opts.getTypeFixesBabelPlugins) && opts.getTypeFixesBabelPlugins({ isJSX });
        if (additionalFixes)
            postMigrationFixes.push(...additionalFixes);
        let ts = tsSyntax.code;
        for (const fixPlugin of postMigrationFixes) {
            const fixResult = yield babel.transformAsync(ts, {
                compact: false,
                babelrc: false,
                configFile: false,
                filename: targetFilePath,
                plugins: [...transformPlugins, fixPlugin],
                generatorOpts: {
                    decoratorsBeforeExport: true,
                },
                parserOpts: {
                    allowReturnOutsideFunction: true,
                    plugins: [
                        'typescript',
                        ...(isJSX ? ['jsx'] : []),
                        ...sharedParserPlugins_1.sharedParserPlugins,
                    ],
                },
            });
            if (fixResult === null) {
                throw new Error('babel.transformSync returned null - probably there is some configuration error');
            }
            ts = fixResult.code;
        }
        let result = ts;
        if (opts === null || opts === void 0 ? void 0 : opts.prettier) {
            let prettierConfig = (_f = opts === null || opts === void 0 ? void 0 : opts.prettierOptions) !== null && _f !== void 0 ? _f : {};
            let configFile;
            try {
                configFile = yield prettier.resolveConfigFile(targetFilePath);
                prettierConfig = (yield prettier.resolveConfig(targetFilePath)) || {};
            }
            catch (e) {
                if (!configFile) {
                    logger.warn(`failed to find prettier config for ${targetFilePath}`);
                }
            }
            try {
                prettierConfig.parser = 'babel-ts';
                result = prettier.format(result, Object.assign(Object.assign({}, prettierConfig), { 
                    // avoid changing template strings
                    embeddedLanguageFormatting: 'off' }));
            }
            catch (e) {
                // retry using different parser - this can be helpful with flow type comments in some edge cases
                prettierConfig.parser = 'typescript';
                try {
                    result = prettier.format(result, Object.assign(Object.assign({}, prettierConfig), { 
                        // avoid changing template strings
                        embeddedLanguageFormatting: 'off' }));
                }
                catch (e) {
                    logger.warn('prettier formatting failed');
                    console.error(e);
                }
            }
        }
        return result;
    });
}
exports.convertFile = convertFile;
//# sourceMappingURL=convertFile.js.map