"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const detectOptions_1 = require("./detectOptions");
describe('detectOptions', () => {
    it('detects @flow comment', () => {
        expect((0, detectOptions_1.detectOptions)(`// @flow`, 'flow.js')).toMatchInlineSnapshot(`
      {
        "hasFlowAnnotation": true,
        "hasNoFlowAnnotation": false,
        "hasTypes": false,
        "isDefinitionFile": false,
        "isJSX": false,
      }
    `);
    });
    it('detects flow constructions in code', () => {
        expect((0, detectOptions_1.detectOptions)(`let a: number = 1;`, 'test.js'))
            .toMatchInlineSnapshot(`
      {
        "hasFlowAnnotation": false,
        "hasNoFlowAnnotation": false,
        "hasTypes": true,
        "isDefinitionFile": false,
        "isJSX": false,
      }
    `);
    });
    it('detects JSX', () => {
        expect((0, detectOptions_1.detectOptions)(`let a = <div/>;`, 'test.js')).toMatchInlineSnapshot(`
      {
        "hasFlowAnnotation": false,
        "hasNoFlowAnnotation": false,
        "hasTypes": false,
        "isDefinitionFile": false,
        "isJSX": true,
      }
    `);
    });
    it('throws', () => {
        expect(() => (0, detectOptions_1.detectOptions)(`let a = /<div/>;`, 'test.js')).toThrow();
    });
    it('use file extension to detect jsx', () => {
        expect((0, detectOptions_1.detectOptions)(`// @flow`, 'flow.jsx')).toMatchInlineSnapshot(`
      {
        "hasFlowAnnotation": true,
        "hasNoFlowAnnotation": false,
        "hasTypes": false,
        "isDefinitionFile": false,
        "isJSX": true,
      }
    `);
    });
    it('use file extension to detect flow', () => {
        expect((0, detectOptions_1.detectOptions)(`let a = 1;`, 'test.js.flow')).toMatchInlineSnapshot(`
      {
        "hasFlowAnnotation": false,
        "hasNoFlowAnnotation": false,
        "hasTypes": false,
        "isDefinitionFile": true,
        "isJSX": false,
      }
    `);
    });
});
//# sourceMappingURL=detectOptions.test.js.map