"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Rule = void 0;
const template_1 = __importDefault(require("@babel/template"));
const t = __importStar(require("@babel/types"));
const traverse_1 = __importDefault(require("@babel/traverse"));
const recast = __importStar(require("@zxbodya/recast"));
const prettier = __importStar(require("prettier"));
const templateOpts = {
    plugins: ['typescript'],
    sourceType: 'module',
};
const buildRuleTemplate = template_1.default.program(`
import { RuleSet } from '../../ruleTypes';

export default {
  globals: {},

  modules: {},
} as RuleSet;
`, templateOpts);
function print(generatedAst, prettierConfig) {
    const code = recast.print(generatedAst);
    return prettier.format(code.code, prettierConfig);
}
function getModuleDescr(moduleObj) {
    let exportsPath;
    for (const prop of moduleObj.get('properties')) {
        if (!prop.isObjectProperty()) {
            throw prop.buildCodeFrameError('modules can be defined only as properties in "modules" object');
        }
        // todo: babel-types
        const value = prop.get('value');
        const key = prop.get('key');
        const keyName = key.isIdentifier()
            ? key.node.name
            : key.isStringLiteral()
                ? key.node.value
                : undefined;
        if (keyName === 'exports') {
            if (!value.isObjectExpression()) {
                throw value.buildCodeFrameError('only object expression is supported for "exports" property');
            }
            exportsPath = value;
        }
    }
    if (!exportsPath) {
        throw moduleObj.buildCodeFrameError('exports definition not found');
    }
    const moduleRules = new Map();
    for (const moduleRule of exportsPath.get('properties')) {
        if (!moduleRule.isObjectMethod()) {
            throw moduleRule.buildCodeFrameError('rules can be defined only as methods on globals object');
        }
        moduleRules.set(moduleRule.node.key, moduleRule);
    }
    return {
        exportsPath: exportsPath,
        exports: moduleRules,
    };
}
class Rule {
    constructor(moduleName, ruleAst) {
        this.moduleName = moduleName;
        this.ruleAst = ruleAst;
        let globalsObjPath;
        let modulesObjPath;
        let hasDefaultExport = false;
        (0, traverse_1.default)(ruleAst, {
            ExportDefaultDeclaration: (path) => {
                hasDefaultExport = true;
                const declaration = path.get('declaration');
                if (declaration.type !== 'TSAsExpression') {
                    throw declaration.buildCodeFrameError('type cast to RuleSet is missing');
                }
                if (!declaration.isExpression()) {
                    throw declaration.buildCodeFrameError('declaration should be an expression');
                }
                const expression = declaration.get('expression');
                if (!expression.isObjectExpression()) {
                    throw declaration.buildCodeFrameError('only object expression is supported');
                }
                // todo: babel-types
                const rootProperties = expression.get('properties');
                for (const rootProperty of rootProperties) {
                    if (rootProperty.isObjectProperty()) {
                        // todo: babel-types
                        const value = rootProperty.get('value');
                        const key = rootProperty.get('key');
                        const keyName = key.isIdentifier()
                            ? key.node.name
                            : key.isStringLiteral()
                                ? key.node.value
                                : undefined;
                        if (keyName === 'globals') {
                            if (!value.isObjectExpression()) {
                                throw value.buildCodeFrameError('only object expression is supported for globals');
                            }
                            globalsObjPath = value;
                        }
                        if (keyName === 'modules') {
                            if (!value.isObjectExpression()) {
                                throw value.buildCodeFrameError('only object expression is supported for modules');
                            }
                            modulesObjPath = value;
                        }
                    }
                }
                if (!globalsObjPath) {
                    throw expression.buildCodeFrameError('globals definition not found');
                }
                if (!modulesObjPath) {
                    throw expression.buildCodeFrameError('modules definition not found');
                }
            },
        });
        if (!hasDefaultExport) {
            throw new Error('default export is missing');
        }
        this.globalsObjPath = globalsObjPath;
        this.modulesObjPath = modulesObjPath;
        const globalRules = new Map();
        for (const globalRule of this.globalsObjPath.get('properties')) {
            if (!globalRule.isObjectMethod()) {
                throw globalRule.buildCodeFrameError('rules can be defined only as methods on globals object');
            }
            // todo: change this to be string
            const globalName = globalRule.node.key;
            globalRules.set(globalName, globalRule);
        }
        const modulesRules = new Map();
        for (const module of this.modulesObjPath.get('properties')) {
            if (!module.isObjectProperty()) {
                throw module.buildCodeFrameError('modules can be defined only as properties in modules object');
            }
            // todo: change this to be string
            const moduleName = module.node.key;
            // todo: babel-types
            const moduleObj = module.get('value');
            if (!moduleObj.isObjectExpression()) {
                throw moduleObj.buildCodeFrameError('only object expression is supported for module rules');
            }
            const moduleRulesDecr = getModuleDescr(moduleObj);
            modulesRules.set(moduleName, moduleRulesDecr);
        }
        let testDescribeBody;
        this.globalRules = globalRules;
        this.moduleRules = modulesRules;
    }
    static create(moduleName) {
        const ruleAst = {
            type: 'File',
            program: buildRuleTemplate(),
        };
        return new Rule(moduleName, ruleAst);
    }
    static parse(ruleSource) {
        throw new Error('todo:');
    }
    print(prettierConfig) {
        return print(this.ruleAst, prettierConfig);
    }
    setGlobalRule(declarationName, fix, comments) {
        const method = fix.length
            ? Object.assign(Object.assign({}, t.objectMethod('method', t.stringLiteral(declarationName), [t.identifier('context')], t.blockStatement(fix))), { comments }) : Object.assign(Object.assign({}, t.objectProperty(t.stringLiteral(declarationName), t.booleanLiteral(false))), { comments });
        this.globalsObjPath.node.properties.push(method);
        const methodPath = this.globalsObjPath.get('properties')[this.globalsObjPath.node.properties.length - 1];
        this.globalRules.set(declarationName, methodPath);
    }
    setModuleRule(moduleName, declarationName, fix, comments) {
        let moduleRules = this.moduleRules.get(moduleName);
        if (!moduleRules) {
            const moduleNode = t.objectProperty(t.stringLiteral(moduleName), t.objectExpression([
                t.objectProperty(t.stringLiteral('exports'), t.objectExpression([])),
            ]));
            this.modulesObjPath.node.properties.push(moduleNode);
            const moduleObj = this.modulesObjPath.get('properties')[this.modulesObjPath.node.properties.length - 1].get('value');
            moduleRules = getModuleDescr(moduleObj);
            this.moduleRules.set(moduleName, moduleRules);
        }
        const fixProperty = fix.length
            ? Object.assign(Object.assign({}, t.objectMethod('method', t.stringLiteral(declarationName), [t.identifier('context')], t.blockStatement(fix))), { comments }) : Object.assign(Object.assign({}, t.objectProperty(t.stringLiteral(declarationName), t.booleanLiteral(false))), { comments });
        moduleRules.exportsPath.node.properties.push(fixProperty);
        const methodPath = moduleRules.exportsPath.get('properties')[moduleRules.exportsPath.node.properties.length - 1];
        moduleRules.exports.set(declarationName, methodPath);
    }
}
exports.Rule = Rule;
//# sourceMappingURL=Rule.js.map