"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RuleTest = void 0;
const template_1 = __importDefault(require("@babel/template"));
const t = __importStar(require("@babel/types"));
const traverse_1 = __importDefault(require("@babel/traverse"));
const recast = __importStar(require("@zxbodya/recast"));
const prettier = __importStar(require("prettier"));
const templateOpts = {
    plugins: ['typescript'],
    sourceType: 'module',
};
const buildTestTemplate = template_1.default.program(`
import plugin from '../../tsTypesPlugin';
import { createTransform } from '../../createTransform';

const transform = createTransform([plugin]);

describe(%%moduleName%%, () => {
  describe('globals', () => {
    test('has no globals', () => {});
  });
  describe('modules', () => {
    test('has no modules', () => {});
  });
});
`, templateOpts);
function print(generatedAst, prettierConfig) {
    const code = recast.print(generatedAst);
    return prettier.format(code.code, prettierConfig);
}
function ifJestCall(functionName, path, fn) {
    if (path.isCallExpression()) {
        // todo babel-types
        const callee = path.get('callee');
        if (callee.isIdentifier()) {
            if (callee.node.name === functionName) {
                // todo babel-types
                const args = path.get('arguments');
                if (args.length === 2) {
                    const testNameArg = args[0];
                    const testFnArg = args[1];
                    if (testNameArg.isStringLiteral() &&
                        (testFnArg.isArrowFunctionExpression() ||
                            testFnArg.isFunctionExpression())) {
                        const name = testNameArg.node.value;
                        const body = testFnArg.get('body');
                        if (!body || !body.isBlockStatement()) {
                            throw body.buildCodeFrameError('test body expected to be block statement');
                        }
                        fn(name, body);
                    }
                }
            }
        }
    }
}
function findJestCalls(functionName, globalsDescribeBody) {
    const tests = new Map();
    for (const path of globalsDescribeBody.get('body')) {
        if (path.isExpressionStatement()) {
            ifJestCall(functionName, path.get('expression'), (name, body) => {
                tests.set(name, body);
            });
        }
    }
    return tests;
}
const HAS_NO_MODULES_TEST_NAME = 'has no modules';
const HAS_NO_GLOBALS_TEST_NAME = 'has no globals';
const HAS_NO_TEST = 'has no test';
function getModuleRulesDescribe(target, moduleName, noDescribesTest, newDescribePlaceholderTest) {
    let moduleDescribe = target.describes.get(moduleName);
    if (!moduleDescribe) {
        const ruleDescribeNode = template_1.default.statement(templateOpts)(`describe(%%moduleName%%, () => {
          test(%%newDescribePlaceholderTest%%, () => {});
       });`)({
            moduleName: t.stringLiteral(moduleName),
            newDescribePlaceholderTest: t.stringLiteral(newDescribePlaceholderTest),
        });
        target.path.node.body.push(ruleDescribeNode);
        const body = target.path.get('body');
        const path = body[body.length - 1].get('expression.arguments.1.body');
        moduleDescribe = {
            path: path,
            describes: new Map([...findJestCalls('describe', path)].map(([ruleName, path]) => [
                ruleName,
                {
                    path,
                    tests: findJestCalls('test', path),
                },
            ])),
            tests: findJestCalls('test', path),
        };
        target.describes.set(moduleName, moduleDescribe);
    }
    const placeholderTest = target.tests.get(noDescribesTest);
    if (placeholderTest) {
        // arrow expression - expression statement
        placeholderTest.parentPath.parentPath.remove();
        target.tests.delete(noDescribesTest);
    }
    return moduleDescribe;
}
function getRulesDescribe(target, declarationName, noDescribesTest, newDescribePlaceholderTest) {
    let ruleTests = target.describes.get(declarationName);
    if (!ruleTests) {
        const ruleDescribeNode = template_1.default.statement(templateOpts)(`describe(%%declarationName%%, () => {
          test(%%newDescribePlaceholderTest%%, () => {});
       });`)({
            declarationName: t.stringLiteral(declarationName),
            newDescribePlaceholderTest: t.stringLiteral(newDescribePlaceholderTest),
        });
        target.path.node.body.push(ruleDescribeNode);
        const body = target.path.get('body');
        const path = body[body.length - 1].get('expression.arguments.1.body');
        ruleTests = {
            path,
            tests: findJestCalls('test', path),
        };
        target.describes.set(declarationName, ruleTests);
    }
    const placeholderTest = target.tests.get(noDescribesTest);
    if (placeholderTest) {
        // arrow expression - expression statement
        placeholderTest.parentPath.parentPath.remove();
        target.tests.delete(noDescribesTest);
    }
    return ruleTests;
}
function refreshTests(rulesDescribe) {
    rulesDescribe.tests = findJestCalls('test', rulesDescribe.path);
    const noTest = rulesDescribe.tests.get(HAS_NO_TEST);
    if (rulesDescribe.tests.size > 1 && noTest) {
        noTest.parentPath.parentPath.remove();
        rulesDescribe.tests.delete(HAS_NO_TEST);
    }
}
class RuleTest {
    constructor(moduleName, testAst) {
        this.moduleName = moduleName;
        this.testAst = testAst;
        let testDescribeBody;
        (0, traverse_1.default)(testAst, {
            CallExpression: (path) => {
                ifJestCall('describe', path, (name, body) => {
                    if (name === this.moduleName) {
                        testDescribeBody = body;
                    }
                });
                path.skip();
            },
        });
        if (!testDescribeBody) {
            throw new Error(`can not find "describe('${this.moduleName}', () => { … })" in test file`);
        }
        const testRootDescribes = findJestCalls('describe', testDescribeBody);
        const globalsDescribeBody = testRootDescribes.get('globals');
        const modulesDescribeBody = testRootDescribes.get('modules');
        if (!globalsDescribeBody) {
            throw testDescribeBody.buildCodeFrameError(`can not find "describe('globals', () => { … })" in test file`);
        }
        if (!modulesDescribeBody) {
            throw testDescribeBody.buildCodeFrameError(`can not find "describe('modules', () => { … })" in test file`);
        }
        const globalRuleTests = {
            describes: new Map([...findJestCalls('describe', globalsDescribeBody)].map(([ruleName, path]) => [
                ruleName,
                {
                    path,
                    tests: findJestCalls('test', path),
                },
            ])),
            path: globalsDescribeBody,
            tests: findJestCalls('test', globalsDescribeBody),
        };
        const moduleRuleTests = {
            describes: new Map([...findJestCalls('describe', modulesDescribeBody)].map(([moduleName, moduleTestBody]) => [
                moduleName,
                {
                    describes: new Map([...findJestCalls('describe', moduleTestBody)].map(([ruleName, path]) => [
                        ruleName,
                        {
                            path,
                            tests: findJestCalls('test', path),
                        },
                    ])),
                    tests: findJestCalls('test', moduleTestBody),
                    path: moduleTestBody,
                },
            ])),
            path: modulesDescribeBody,
            tests: findJestCalls('test', modulesDescribeBody),
        };
        this.globalRuleTests = globalRuleTests;
        this.moduleRuleTests = moduleRuleTests;
    }
    static create(moduleName) {
        const testAst = {
            type: 'File',
            program: buildTestTemplate({
                moduleName: t.stringLiteral(moduleName),
            }),
        };
        return new RuleTest(moduleName, testAst);
    }
    static parse(testSource) {
        throw new Error('todo:');
    }
    print(prettierConfig) {
        return print(this.testAst, prettierConfig);
    }
    setGlobalRuleTests(declarationName, tests) {
        const rulesDescribe = getRulesDescribe(this.globalRuleTests, declarationName, HAS_NO_GLOBALS_TEST_NAME, 'has no test');
        rulesDescribe.path.node.body.push(...tests);
        refreshTests(rulesDescribe);
    }
    setModuleRuleTests(moduleName, declarationName, tests) {
        const moduleRulesDescribe = getModuleRulesDescribe(this.moduleRuleTests, moduleName, HAS_NO_MODULES_TEST_NAME, 'has no test');
        const rulesDescribe = getRulesDescribe(moduleRulesDescribe, declarationName, 'has no test', 'has no test');
        rulesDescribe.path.node.body.push(...tests);
        refreshTests(rulesDescribe);
    }
}
exports.RuleTest = RuleTest;
//# sourceMappingURL=RuleTest.js.map