"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const babel = __importStar(require("@babel/core"));
const traverse_1 = __importDefault(require("@babel/traverse"));
const t = __importStar(require("@babel/types"));
const fs = __importStar(require("fs"));
const prettier = __importStar(require("prettier"));
const Rule_1 = require("./Rule");
const generateTests_1 = require("./generateTests");
const RuleTest_1 = require("./RuleTest");
const sharedParserPlugins = [
    'jsx',
    'classProperties',
    'objectRestSpread',
    'optionalChaining',
    'dynamicImport',
];
function main(inputPath, outputPath, referenceName) {
    return __awaiter(this, void 0, void 0, function* () {
        console.log(`generating rules stub for ${inputPath}`);
        const rule = Rule_1.Rule.create(referenceName);
        const ruleTest = RuleTest_1.RuleTest.create(referenceName);
        const source = fs.readFileSync(inputPath, { encoding: 'utf8' });
        const flowAst = babel.parseSync(source, {
            babelrc: false,
            ast: true,
            plugins: [],
            parserOpts: {
                allowReturnOutsideFunction: true,
                plugins: [['flow', { enums: true }], ...sharedParserPlugins],
            },
            filename: inputPath,
            sourceFileName: inputPath,
            sourceType: 'unambiguous',
        });
        // @ts-ignore
        new babel.File({ filename: inputPath }, { code: source, ast: flowAst });
        if (flowAst === null) {
            throw new Error('sourceAst === null');
        }
        const globals = new Map();
        let isModule = false;
        let moduleName;
        const modules = {};
        let module;
        let hasExports = false;
        const defaultModule = new Map();
        function register(target, name, path) {
            let ent = target.get(name);
            if (ent === undefined) {
                ent = { paths: [], fix: [] };
                target.set(name, ent);
            }
            ent.paths.push(path);
        }
        const registerGlobal = (name, path) => register(globals, name, path);
        const registerModule = (name, path) => register(module, name, path);
        const registerDefaultModule = (name, path) => {
            hasExports = true;
            register(defaultModule, name, path);
        };
        (0, traverse_1.default)(flowAst, {
            DeclareClass(path) {
                if (!isModule) {
                    registerGlobal(path.node.id.name, path);
                }
                else {
                    if (!t.isDeclareExportDeclaration(path.parent)) {
                        registerModule(path.node.id.name, path);
                    }
                }
            },
            DeclareFunction(path) {
                if (!isModule) {
                    registerGlobal(path.node.id.name, path);
                }
                else {
                    if (!t.isDeclareExportDeclaration(path.parent)) {
                        registerModule(path.node.id.name, path);
                    }
                }
            },
            DeclareInterface(path) {
                if (!isModule) {
                    registerGlobal(path.node.id.name, path);
                }
                else {
                    if (!t.isDeclareExportDeclaration(path.parent)) {
                        registerModule(path.node.id.name, path);
                    }
                }
            },
            DeclareTypeAlias(path) {
                if (!isModule) {
                    registerGlobal(path.node.id.name, path);
                }
                else {
                    if (!t.isDeclareExportDeclaration(path.parent)) {
                        registerModule(path.node.id.name, path);
                    }
                }
            },
            DeclareOpaqueType(path) {
                if (!isModule) {
                    registerGlobal(path.node.id.name, path);
                }
                else {
                    if (!t.isDeclareExportDeclaration(path.parent)) {
                        registerModule(path.node.id.name, path);
                    }
                }
            },
            DeclareVariable(path) {
                if (!isModule) {
                    registerGlobal(path.node.id.name, path);
                }
                else {
                    if (!t.isDeclareExportDeclaration(path.parent)) {
                        registerModule(path.node.id.name, path);
                    }
                }
            },
            DeclareModule: {
                enter(path) {
                    isModule = true;
                    moduleName = t.isIdentifier(path.node.id)
                        ? path.node.id.name
                        : path.node.id.value;
                    module = new Map();
                },
                exit() {
                    isModule = false;
                    modules[moduleName] = module;
                },
            },
            DeclareModuleExports(path) {
                console.log('module.exports are treated as default export');
                if (!isModule) {
                    registerDefaultModule('default', path);
                }
                else {
                    registerModule('default', path);
                }
            },
            DeclareExportDeclaration(path) {
                if (isModule) {
                    const declaration = path.get('declaration');
                    if (declaration.isDeclareClass() ||
                        declaration.isDeclareFunction() ||
                        declaration.isDeclareInterface() ||
                        declaration.isTypeAlias() ||
                        declaration.isDeclareVariable()) {
                        if (!isModule) {
                            registerDefaultModule(declaration.node.id.name, path);
                        }
                        else {
                            registerModule(declaration.node.id.name, path);
                        }
                    }
                    else if (t.isOpaqueType(declaration.node)) {
                        const decl = declaration;
                        // todo: improve @babel/types to include path.isOpaqueType()
                        if (!isModule) {
                            registerDefaultModule(decl.node.id.name, path);
                        }
                        else {
                            registerModule(decl.node.id.name, path);
                        }
                    }
                    else if (path.node.default) {
                        if (!isModule) {
                            registerDefaultModule('default', path);
                        }
                        else {
                            registerModule('default', path);
                        }
                    }
                    else {
                        throw path.buildCodeFrameError('not implemented');
                    }
                }
                else {
                    throw path.buildCodeFrameError('not implemented');
                }
            },
            DeclareExportAllDeclaration(path) {
                throw path.buildCodeFrameError('not implemented');
            },
        });
        if (hasExports) {
            modules.exports = defaultModule;
        }
        for (const [globalName, state] of globals) {
            // console.log(globals, modules);
            // very often globals are re-exported as aliases in modules below
            const parts = globalName.split('$');
            if (parts.length === 2) {
                const moduleName = parts[0].toLowerCase();
                const exportName = parts[1];
                if (modules[moduleName] && modules[moduleName].has(exportName)) {
                    state.fix.push(t.expressionStatement(t.callExpression(t.memberExpression(t.identifier('context'), t.identifier('import'), false), [t.stringLiteral(moduleName), t.stringLiteral(exportName)])));
                }
            }
        }
        function getNodeComment(path) {
            const blocks = [''];
            blocks.push(path.getSource().replace(/(?:\/\*|\*\/)/g, ''));
            blocks.push('');
            return {
                type: 'CommentBlock',
                value: blocks.join('\n'),
            };
        }
        for (const [declarationName, { paths, fix }] of globals) {
            const comments = paths.map(path => {
                return getNodeComment(path);
            });
            rule.setGlobalRule(declarationName, fix, comments);
            ruleTest.setGlobalRuleTests(declarationName, (0, generateTests_1.generateGlobalTests)(declarationName, paths));
        }
        for (const [moduleName, declarations] of Object.entries(modules)) {
            for (const [declarationName, { paths }] of declarations) {
                const comments = paths.map(path => {
                    return getNodeComment(path);
                });
                rule.setModuleRule(moduleName, declarationName, [], comments);
                ruleTest.setModuleRuleTests(moduleName, declarationName, (0, generateTests_1.generateModuleTests)(moduleName, declarationName, paths));
            }
        }
        const prettierConfig = (yield prettier.resolveConfig('./')) || {};
        prettierConfig.parser = 'babel-ts';
        const ruleCode = rule.print(prettierConfig);
        const testCode = ruleTest.print(prettierConfig);
        fs.writeFileSync(outputPath, ruleCode);
        fs.writeFileSync(outputPath.replace(/\.ts$/, '.test.ts'), testCode);
    });
}
main(process.argv[2], process.argv[3], process.argv[4]).then(() => {
    console.log('done');
}, e => {
    console.error(e);
});
//# sourceMappingURL=generateRules.js.map