"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateModuleTests = exports.generateGlobalTests = void 0;
const t = __importStar(require("@babel/types"));
function getParamsConfig(typeParameters) {
    let paramsCount = 0;
    let requiredParamsCount = 0;
    if (typeParameters) {
        paramsCount = typeParameters.params.length;
        requiredParamsCount = typeParameters.params.filter(p => !p.default).length;
    }
    return { paramsCount, requiredParamsCount };
}
const spaces = '                                                           ';
function createTest(name, content, identation) {
    const lastIdent = spaces.substr(0, identation);
    const contentIdent = spaces.substr(0, identation + 2);
    return t.expressionStatement(t.callExpression(t.identifier('test'), [
        t.stringLiteral(name),
        t.arrowFunctionExpression([], t.blockStatement([
            t.expressionStatement(t.callExpression(t.memberExpression(t.callExpression(t.identifier('expect'), [
                t.callExpression(t.identifier('transform'), [
                    t.templateLiteral([
                        t.templateElement({
                            raw: [
                                '',
                                ...content.map(v => contentIdent + v),
                                lastIdent,
                            ].join('\n'),
                        }),
                    ], []),
                ]),
            ]), t.identifier('toMatchSnapshot')), [])),
        ])),
    ]));
}
function getTypeParamName(paramsConfig) {
    if (paramsConfig.requiredParamsCount === paramsConfig.paramsCount) {
        if (paramsConfig.requiredParamsCount === 0)
            return '';
        return `typeParams(${paramsConfig.requiredParamsCount})`;
    }
    else {
        return `typeParams(${paramsConfig.requiredParamsCount} - ${paramsConfig.paramsCount})`;
    }
}
function generateClassTests(classes, baseTestName, reference, prepend = []) {
    let testName = baseTestName;
    const tests = [];
    for (const [confName, paramsConfig] of classes) {
        let classNameIndex = 1;
        let varNameIndex = 1;
        if (confName) {
            testName += ` - ${confName}`;
        }
        const testBody = [];
        if (prepend.length) {
            testBody.push(...prepend, '');
        }
        // assuming params are inferred
        testBody.push(`new ${reference}();`, '');
        for (let paramsCount = paramsConfig.requiredParamsCount; paramsCount <= paramsConfig.paramsCount; paramsCount += 1) {
            if (paramsCount > 0) {
                const params = new Array(paramsCount)
                    .fill('')
                    .map((_, index) => `P${index}`)
                    .join(', ');
                testBody.push(`class A${classNameIndex} extends ${reference}<${params}> {}`, `let a${varNameIndex} = new ${reference}<${params}>();`, '');
            }
            else {
                testBody.push(`class A${classNameIndex} extends ${reference} {};`);
            }
            classNameIndex += 1;
            varNameIndex += 1;
        }
        tests.push(createTest(testName, testBody, 10));
    }
    return tests;
}
function generateInterfaceTests(interfaces, baseTestName, reference, prepend = []) {
    let testName = baseTestName;
    const tests = [];
    for (const [confName, paramsConfig] of interfaces) {
        let classNameIndex = 1;
        let interfaceNameCount = 1;
        if (confName) {
            testName += ` - ${confName}`;
        }
        const testBody = [];
        if (prepend.length) {
            testBody.push(...prepend, '');
        }
        for (let paramsCount = paramsConfig.requiredParamsCount; paramsCount <= paramsConfig.paramsCount; paramsCount += 1) {
            if (paramsCount > 0) {
                const params = new Array(paramsCount)
                    .fill('')
                    .map((_, index) => `P${index}`)
                    .join(', ');
                testBody.push(`class A${classNameIndex} implements ${reference}<${params}> {}`, `interface I${interfaceNameCount} extends ${reference}<${params}> {}`, '');
            }
            else {
                testBody.push(`class A${classNameIndex} implements ${reference} {};`);
            }
            classNameIndex += 1;
            interfaceNameCount += 1;
        }
        tests.push(createTest(testName, testBody, 10));
    }
    return tests;
}
function generateCallableTests(functions, baseTestName, reference, prepend = []) {
    let testName = baseTestName;
    const tests = [];
    for (const [confName, paramsConfig] of functions) {
        let varNameIndex = 1;
        if (confName) {
            testName += ` - ${confName}`;
        }
        const testBody = [];
        if (prepend.length) {
            testBody.push(...prepend, '');
        }
        // assuming params are inferred
        testBody.push(`${reference}();`, '');
        for (let paramsCount = paramsConfig.requiredParamsCount; paramsCount <= paramsConfig.paramsCount; paramsCount += 1) {
            if (paramsCount > 0) {
                const params = new Array(paramsCount)
                    .fill('')
                    .map((_, index) => `P${index}`)
                    .join(', ');
                testBody.push(`let a${varNameIndex} = ${reference}<${params}>();`);
            }
            varNameIndex += 1;
        }
        tests.push(createTest(testName, testBody, 10));
    }
    return tests;
}
function generateTypeTests(types, baseTestName, reference, prepend = []) {
    let testName = baseTestName;
    const tests = [];
    for (const [confName, paramsConfig] of types) {
        let varNameIndex = 1;
        if (confName) {
            testName += ` - ${confName}`;
        }
        const testBody = [];
        if (prepend.length) {
            testBody.push(...prepend, '');
        }
        for (let paramsCount = paramsConfig.requiredParamsCount; paramsCount <= paramsConfig.paramsCount; paramsCount += 1) {
            if (paramsCount > 0) {
                const params = new Array(paramsCount)
                    .fill('')
                    .map((_, index) => `P${index}`)
                    .join(', ');
                testBody.push(`let a${varNameIndex}: ${reference}<${params}>;`);
            }
            varNameIndex += 1;
        }
        tests.push(createTest(testName, testBody, 10));
    }
    return tests;
}
function collectPathsData(paths) {
    let isVariable = false;
    const callable = new Map();
    const classes = new Map();
    const interfaceType = new Map();
    const type = new Map();
    for (const basePath of paths) {
        const path = basePath.node.type === 'DeclareExportDeclaration'
            ? basePath.get('declaration')
            : basePath;
        if (path.isDeclareClass()) {
            const typeParameters = path.node.typeParameters;
            const paramsConfig = getParamsConfig(typeParameters);
            classes.set(getTypeParamName(paramsConfig), paramsConfig);
            isVariable = true;
        }
        if (path.isDeclareFunction()) {
            isVariable = true;
            const typeAnnotation = path.get('id').get('typeAnnotation');
            if (typeAnnotation.isTypeAnnotation()) {
                const fnTypeAnnotation = typeAnnotation.get('typeAnnotation');
                if (fnTypeAnnotation.isFunctionTypeAnnotation()) {
                    const paramsConfig = getParamsConfig(fnTypeAnnotation.node.typeParameters);
                    classes.set(getTypeParamName(paramsConfig), paramsConfig);
                    callable.set(getTypeParamName(paramsConfig), paramsConfig);
                }
            }
        }
        if (path.isDeclareInterface()) {
            const paramsConfig = getParamsConfig(path.node.typeParameters);
            type.set(getTypeParamName(paramsConfig), paramsConfig);
            interfaceType.set(getTypeParamName(paramsConfig), paramsConfig);
        }
        if (path.isDeclareTypeAlias() || path.isTypeAlias()) {
            const paramsConfig = getParamsConfig(path.node.typeParameters);
            type.set(getTypeParamName(paramsConfig), paramsConfig);
        }
        if (path.type === 'DeclareOpaqueType') {
            const paramsConfig = getParamsConfig(null);
            type.set(getTypeParamName(paramsConfig), paramsConfig);
        }
        if (path.isDeclareVariable()) {
            isVariable = true;
            // todo: namespace
            // todo: function and arrow function
            // todo: class
        }
    }
    return { isVariable, callable, classes, type };
}
function generateGlobalTests(name, paths) {
    const { isVariable, callable, classes, type } = collectPathsData(paths);
    const tests = [];
    if (isVariable) {
        tests.push(createTest('variable', ['var a = ' + name + ';'], 10));
    }
    tests.push(...generateClassTests(classes, 'generated - class', name));
    tests.push(...generateCallableTests(callable, 'generated - callable', name));
    tests.push(...generateTypeTests(type, 'generated - type', name));
    tests.push(...generateInterfaceTests(type, 'generated - interface', name));
    return tests;
}
exports.generateGlobalTests = generateGlobalTests;
function generateModuleTests(moduleName, name, paths) {
    const { isVariable, callable, classes, type } = collectPathsData(paths);
    const tests = [];
    if (isVariable) {
        tests.push(createTest('variable', ['var a = ' + name + ';'], 10));
    }
    const confs = [
        {
            prepend: (isType) => [
                `import ${isType ? 'type ' : ''}{ ${name} } from "${moduleName}";`,
            ],
            importName: name,
            prefix: '',
        },
        {
            prepend: (isType) => [`import * as M from "${moduleName}";`],
            importName: 'M.' + name,
            prefix: ' - import namespace',
        },
        {
            prepend: (isType) => [
                `import ${isType ? 'type ' : ''}{ ${name} as t } from "${moduleName}";`,
            ],
            importName: 't',
            prefix: ' - import renamed',
        },
    ];
    for (const conf of confs) {
        tests.push(...generateClassTests(classes, `generated - class${conf.prefix}`, conf.importName, conf.prepend(false)));
        tests.push(...generateCallableTests(callable, `generated - callable${conf.prefix}`, conf.importName, conf.prepend(false)));
        tests.push(...generateTypeTests(type, `generated - type${conf.prefix}`, conf.importName, conf.prepend(true)));
        tests.push(...generateInterfaceTests(type, `generated - interface${conf.prefix}`, conf.importName, conf.prepend(true)));
    }
    return tests;
}
exports.generateModuleTests = generateModuleTests;
//# sourceMappingURL=generateTests.js.map