"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const removeImportExtensionPlugin_1 = __importDefault(require("./removeImportExtensionPlugin"));
const createTransform_1 = require("./createTransform");
const transform = (0, createTransform_1.createTransform)([removeImportExtensionPlugin_1.default]);
describe('removeImportExtensionPlugin', () => {
    test('imports are removed', () => {
        expect(transform(`
import { Component } from 'react';
import R from 'react-dom';
import './a.css';
import './a.js';
import './b.js.flow';

class C extends Component {}
`)).toMatchInlineSnapshot(`
      "import { Component } from "react";
      import R from "react-dom";
      import "./a.css";
      import "./a";
      import "./b";

      class C extends Component {}
      "
    `);
    });
    test('dynamic imports', () => {
        expect(transform(`
const a = import('./a.js');
`)).toMatchInlineSnapshot(`
      "const a = import("./a");
      "
    `);
    });
    test('jest.mock', () => {
        expect(transform(`
jest.mock('./a.js');
jest.unmock('./a.js');
jest.doMock('./a.js');
jest.dontMock('./a.js');
jest.setMock('./a.js');
jest.requireActual('./a.js');
jest.requireMock('./a.js');
`)).toMatchInlineSnapshot(`
      "jest.mock("./a");
      jest.unmock("./a");
      jest.doMock("./a");
      jest.dontMock("./a");
      jest.setMock("./a");
      jest.requireActual("./a");
      jest.requireMock("./a");
      "
    `);
    });
    test('require', () => {
        expect(transform(`
const a = require('./a.js');
`)).toMatchInlineSnapshot(`
      "const a = require("./a");
      "
    `);
    });
});
//# sourceMappingURL=removeImportExtensionPlugin.test.js.map