"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander = __importStar(require("commander"));
const fs = __importStar(require("fs"));
const fs_1 = require("fs");
const path = __importStar(require("path"));
const globby_1 = __importDefault(require("globby"));
const ora_1 = __importDefault(require("ora"));
const updateComments_1 = require("./updateComments");
const program = new commander.Command();
const pkg = JSON.parse(fs.readFileSync(path.resolve(__dirname, '../package.json'), 'utf8'));
program
    .name('flowts-uncomment-flow-types')
    .version(pkg.version)
    .description('Helper to uncomment flow types')
    .option('--no-gitignore', 'also include files which are listed in gitignore files', true)
    .usage('[options] ./path/to/project')
    .option('-i, --include <includeGlob>', 'Glob expression of files to include, default: "**/*.{js,mjs,jsx,js.flow}"', '**/*.{js,mjs,jsx,js.flow}')
    .option('-x, --exclude <excludeGlob>', 'Additional excludes glob expression (by default node_modules and files from .gitignore is excluded)', (a, b) => [...b, a], [])
    .option('--dry-run', 'Do not save changes after migration', false)
    .parse(process.argv);
const args = program.args;
const opts = program.opts();
if (args.length === 0) {
    console.error('Please specify project root');
    process.exit(1);
}
if (args.length > 1) {
    console.error('Only one project root can be specified');
    process.exit(1);
}
const { exclude: excludeGlobs } = opts, restOptions = __rest(opts, ["exclude"]);
const convertOptions = Object.assign(Object.assign({}, restOptions), { exclude: ['**/node_modules/**', ...excludeGlobs] });
function uncommentFlowTypes(cwd, opts) {
    return __awaiter(this, void 0, void 0, function* () {
        console.log('options:', opts);
        const spinner = (0, ora_1.default)().start(`processing files in ${cwd}`);
        const files = yield (0, globby_1.default)(opts.include, {
            cwd,
            onlyFiles: true,
            dot: true,
            ignore: opts.exclude,
            gitignore: opts.gitignore,
        });
        spinner.info('uncommenting types');
        const totalStr = `${files.length}`;
        let currentCount = 0;
        for (const file of files) {
            const currentStr = `${currentCount}`.padStart(totalStr.length, ' ');
            spinner.start(`[${currentStr}/${totalStr}] ${file}`);
            try {
                const filepath = path.join(cwd, file);
                const source = yield fs_1.promises.readFile(filepath, { encoding: 'utf8' });
                const result = (0, updateComments_1.updateComments)(source, comment => {
                    const longExp = /^\s*(?:::|flow-include\s)\s*(.*)$/s;
                    // /*::
                    // type MyAlias = {
                    //   foo: number,
                    //   bar: boolean,
                    //   baz: string,
                    // };
                    // */
                    // /*flow-include
                    // type Foo = {
                    //   foo: number,
                    //   bar: boolean,
                    //   baz: string
                    // };
                    // */
                    // function method(param /*:: : string */) /*:: : number */ {
                    const longMatch = comment.value.match(longExp);
                    if (longMatch) {
                        return { type: 'replace', code: longMatch[1] };
                    }
                    const shortExp = /^\s*:\s*(.*)$/s;
                    // function method(value /*: MyAlias */) /*: boolean */ {
                    const shortMatch = comment.value.match(shortExp);
                    if (shortMatch) {
                        return { type: 'replace', code: ':' + shortMatch[1] };
                    }
                    return { type: 'skip' };
                }, {
                    isJSX: true,
                    syntax: 'flow',
                    filename: filepath,
                });
                if (!opts.dryRun) {
                    yield fs_1.promises.writeFile(filepath, result);
                }
            }
            catch (e) {
                spinner.fail(file);
                spinner.fail('error while trying to detect options');
                console.error(e);
                spinner.start();
            }
            currentCount += 1;
        }
        spinner.succeed('finished');
    });
}
uncommentFlowTypes(args[0], convertOptions).then(() => {
    console.log('done');
    process.exit(0);
}, e => {
    console.error(e);
    process.exit(1);
});
//# sourceMappingURL=uncommentFlowTypes.js.map