"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateComments = void 0;
const babel = __importStar(require("@babel/core"));
const sharedParserPlugins_1 = require("./sharedParserPlugins");
const traverse_1 = __importDefault(require("@babel/traverse"));
/**
 * Helper to update fix comments.
 *
 * This is to be used to removing/replacing code in place of comments, instead of using babel plugin.
 * Reason is - babel generator does not preserve formatting. recast has bugs for this kind of changes.
 *
 * @param source
 * @param transform
 * @param options
 */
function updateComments(source, transform, options) {
    var _a, _b, _c;
    const isJSX = options.isJSX;
    const jsxPlugin = isJSX ? ['jsx'] : [];
    const filename = (_a = options.filename) !== null && _a !== void 0 ? _a : 'source' + (options.syntax === 'flow' ? '.js' : '.ts');
    const ast = babel.parseSync(source, {
        compact: false,
        babelrc: false,
        configFile: false,
        ast: true,
        parserOpts: {
            allowReturnOutsideFunction: true,
            plugins: [
                options.syntax === 'flow' ? ['flow', { enums: true }] : 'typescript',
                ...jsxPlugin,
                ...sharedParserPlugins_1.sharedParserPlugins,
            ],
        },
        filename,
    });
    if (ast === null) {
        throw new Error('babel.parseSync returned null - probably there is some configuration error');
    }
    // workaround to have "scope.hub"
    // @ts-ignore
    new babel.File({ filename }, { code: source, ast });
    let comments = [];
    (0, traverse_1.default)(ast, {
        Program(path) {
            path.traverse({
                enter: function ({ node }) {
                    if (node.leadingComments)
                        comments.push(...node.leadingComments);
                    if (node.innerComments)
                        comments.push(...node.innerComments);
                    if (node.trailingComments)
                        comments.push(...node.trailingComments);
                },
            });
        },
    });
    comments = [...new Set(comments)];
    const operations = comments
        .map(comment => ({
        comment,
        operation: transform(comment),
    }))
        .filter(({ operation }) => operation.type !== 'skip');
    operations.sort((a, b) => { var _a, _b, _c; return ((_a = a.comment.start) !== null && _a !== void 0 ? _a : 0) - ((_c = (_b = b.comment) === null || _b === void 0 ? void 0 : _b.start) !== null && _c !== void 0 ? _c : 0); });
    const parts = [];
    let start = 0;
    let removeBrace = false;
    for (const { comment, operation } of operations) {
        // code before comment
        parts.push(source.substring(start, comment.start));
        if (operation.type === 'remove') {
            // comment is skipped
            if (comment.type === 'CommentLine') {
                // if there is empty line to be in place of removed comment line - remove it
                parts[parts.length - 1] = parts[parts.length - 1].replace(/\n(?: |\t)*$/, '');
            }
            if (comment.type === 'CommentBlock') {
                const rest = source.substring((_b = comment.end) !== null && _b !== void 0 ? _b : 0);
                // check if there are other code in the line after the comment
                if (/^\s*\n/.test(rest)) {
                    // if there is empty line to be in place of removed comment line - remove it
                    parts[parts.length - 1] = parts[parts.length - 1].replace(/\n(?: |\t)*$/, '');
                }
                else {
                    // check if comment was inside jsx empty expression - {/* something */}
                    if (/^}\s*\n/.test(rest) && /{$/.test(parts[parts.length - 1])) {
                        // if there is empty line to be in place of removed comment line - remove it
                        parts[parts.length - 1] = parts[parts.length - 1].replace(/\n(?: |\t)*{$/, '');
                        removeBrace = true;
                    }
                }
            }
        }
        else if (operation.type === 'replace') {
            // replacement
            parts.push(operation.code);
        }
        start = (_c = comment.end) !== null && _c !== void 0 ? _c : 0;
        if (removeBrace) {
            // pending "}" to be removed in jsx
            removeBrace = false;
            start += 1;
        }
    }
    // remaining code till end of file
    parts.push(source.substring(start));
    let result = parts.join('');
    if (result[0] === '\n' && source[0] !== '\n') {
        result = result.substring(1);
    }
    return result;
}
exports.updateComments = updateComments;
//
// const USELESS_FLOW_COMMENT_EXPS = [
//   /^\s*\$FlowFixMe suppressed for compatibility with web-code migration\s*$/i,
// ] as const;
// const updateComments = (comments: t.Comment[]) => {
//   // comments.forEach((item) => {
//   //   if (/\$FlowFixMe/i.test(item.value)) {
//   //     console.log({ value: item.value });
//   //   }
//   // });
//   const commentIndex = comments.findIndex(item => {
//     return USELESS_FLOW_COMMENT_EXPS.some(exp => exp.test(item.value));
//   });
//   if (commentIndex !== -1) {
//     comments.splice(commentIndex, 1);
//     return true;
//   }
//   return false;
// };
//# sourceMappingURL=updateComments.js.map