"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.verify = void 0;
const babel = __importStar(require("@babel/core"));
const prettier = __importStar(require("prettier"));
const sharedParserPlugins_1 = require("../sharedParserPlugins");
const removeImportExtensionPlugin_1 = __importDefault(require("../removeImportExtensionPlugin"));
const removeExportAllTypePlugin_1 = __importDefault(require("./removeExportAllTypePlugin"));
const removeEmptyExportPlugin_1 = __importDefault(require("./removeEmptyExportPlugin"));
const removeEnumsPlugin_1 = __importDefault(require("./removeEnumsPlugin"));
const transformTypeOnlyImports_1 = __importDefault(require("./transformTypeOnlyImports"));
// self verification
//  - remove types
//  - remove comments
//  - remove exportKind for export all declarations in flow (it is not yet supported by typescript, and so replaced with regular export all)
//  - reformat using prettier
//  - compare the text
//
// assumption is that if converter works correctly - there should be no difference in resulting js code
function verify(source, result, isJSX, filename, target, isConvertedFile) {
    const jsxPlugin = isJSX ? ['jsx'] : [];
    let srcFixed = babel.transformSync(source, {
        compact: true,
        babelrc: false,
        configFile: false,
        filename,
        plugins: [removeExportAllTypePlugin_1.default, removeEnumsPlugin_1.default],
        presets: [
            [require.resolve('@babel/preset-flow'), { allowDeclareFields: true }],
        ],
        generatorOpts: {
            decoratorsBeforeExport: true,
        },
        parserOpts: {
            allowReturnOutsideFunction: true,
            plugins: [
                ['flow', { enums: true }],
                ...jsxPlugin,
                ...sharedParserPlugins_1.sharedParserPlugins,
            ],
        },
    });
    if (srcFixed === null) {
        throw new Error('result of babel transform is null, likely configuration error');
    }
    srcFixed = babel.transformSync(srcFixed.code, {
        compact: true,
        babelrc: false,
        configFile: false,
        filename,
        comments: false,
        generatorOpts: {
            decoratorsBeforeExport: true,
        },
        plugins: [
            removeEmptyExportPlugin_1.default,
            ...(isConvertedFile
                ? [[removeImportExtensionPlugin_1.default, { isConvertedFile }]]
                : []),
        ],
        parserOpts: {
            allowReturnOutsideFunction: true,
            plugins: [...jsxPlugin, ...sharedParserPlugins_1.sharedParserPlugins],
        },
    });
    if (srcFixed === null) {
        throw new Error('result of babel transform is null, likely configuration error');
    }
    const resultFixTypeImports = babel.transformSync(result, {
        compact: true,
        babelrc: false,
        configFile: false,
        filename: target,
        generatorOpts: {
            decoratorsBeforeExport: true,
        },
        plugins: [transformTypeOnlyImports_1.default],
        presets: [],
        parserOpts: {
            allowReturnOutsideFunction: true,
            plugins: ['typescript', ...jsxPlugin, ...sharedParserPlugins_1.sharedParserPlugins],
        },
    });
    if (resultFixTypeImports === null) {
        throw new Error('result of babel transform is null, likely configuration error');
    }
    let resultNoTypes = babel.transformSync(resultFixTypeImports.code, {
        compact: true,
        babelrc: false,
        configFile: false,
        filename: target,
        generatorOpts: {
            decoratorsBeforeExport: true,
        },
        plugins: [removeEnumsPlugin_1.default],
        presets: [
            [
                require.resolve('@babel/preset-typescript'),
                { onlyRemoveTypeImports: true, allowDeclareFields: true },
            ],
        ],
        parserOpts: {
            allowReturnOutsideFunction: true,
            plugins: ['typescript', ...jsxPlugin, ...sharedParserPlugins_1.sharedParserPlugins],
        },
    });
    if (resultNoTypes === null) {
        throw new Error('result of babel transform is null, likely configuration error');
    }
    resultNoTypes = babel.transformSync(resultNoTypes.code, {
        compact: true,
        babelrc: false,
        configFile: false,
        filename: target,
        comments: false,
        plugins: [removeEmptyExportPlugin_1.default],
        generatorOpts: {
            decoratorsBeforeExport: true,
        },
        parserOpts: {
            allowReturnOutsideFunction: true,
            plugins: [...jsxPlugin, ...sharedParserPlugins_1.sharedParserPlugins],
        },
    });
    if (resultNoTypes === null) {
        throw new Error('result of babel transform is null, likely configuration error');
    }
    const src = prettier.format(srcFixed.code, {
        parser: 'babel',
        // avoid changing template strings
        embeddedLanguageFormatting: 'off',
    });
    const tgt = prettier.format(resultNoTypes.code, {
        parser: 'babel',
        // avoid changing template strings
        embeddedLanguageFormatting: 'off',
    });
    return { isEqual: src === tgt, src, tgt };
}
exports.verify = verify;
//# sourceMappingURL=verify.js.map